@@ -1,6 +1,4 @@
-// This Source Code Form is subject to the terms of the Mozilla Public
-// License, v. 2.0. If a copy of the MPL was not distributed with this
-// file, You can obtain one at https://mozilla.org/MPL/2.0/.
+// SPDX-License-Identifier: MPL-2.0
 
 //! [`Group`].
 
@@ -23,7 +21,11 @@ impl<'ui> Ui<'ui> {
     }
 }
 
-def_subcontrol!(ty: Group, handle: uiGroup,);
+def_subcontrol!(
+    docs: "",
+    ty: Group,
+    handle: uiGroup,
+);
 
 impl<'ui> Group<'ui> {
     bind_text_fn!(
