@@ -1,6 +1,4 @@
-// This Source Code Form is subject to the terms of the Mozilla Public
-// License, v. 2.0. If a copy of the MPL was not distributed with this
-// file, You can obtain one at https://mozilla.org/MPL/2.0/.
+// SPDX-License-Identifier: MPL-2.0
 
 //! [`Image`].
 
@@ -22,7 +20,11 @@ impl<'ui> Ui<'ui> {
     }
 }
 
-def_subcontrol!(ty: Image, handle: uiImage,);
+def_subcontrol!(
+    docs: "",
+    ty: Image,
+    handle: uiImage,
+);
 
 #[repr(C)]
 pub struct Pixel {
