@@ -1,6 +1,4 @@
-// This Source Code Form is subject to the terms of the Mozilla Public
-// License, v. 2.0. If a copy of the MPL was not distributed with this
-// file, You can obtain one at https://mozilla.org/MPL/2.0/.
+// SPDX-License-Identifier: MPL-2.0
 
 //! [`Label`].
 
@@ -23,7 +21,11 @@ impl<'ui> Ui<'ui> {
     }
 }
 
-def_subcontrol!(ty: Label, handle: uiLabel,);
+def_subcontrol!(
+    docs: "",
+    ty: Label,
+    handle: uiLabel,
+);
 
 impl Label<'_> {
     bind_text_fn!(
