@@ -1,6 +1,4 @@
-// This Source Code Form is subject to the terms of the Mozilla Public
-// License, v. 2.0. If a copy of the MPL was not distributed with this
-// file, You can obtain one at https://mozilla.org/MPL/2.0/.
+// SPDX-License-Identifier: MPL-2.0
 
 use super::Menu;
 use crate::prelude::*;
@@ -89,7 +87,7 @@ impl<'ui> Item<'ui> {
         uiMenuItemSetChecked,
     );
 
-    fn as_ptr(&self) -> *mut uiMenuItem {
+    pub(crate) fn as_ptr(&self) -> *mut uiMenuItem {
         self.ptr
     }
 }
