@@ -1,11 +1,8 @@
-// This Source Code Form is subject to the terms of the Mozilla Public
-// License, v. 2.0. If a copy of the MPL was not distributed with this
-// file, You can obtain one at https://mozilla.org/MPL/2.0/.
+// SPDX-License-Identifier: MPL-2.0
 
 //! [`Tab`].
 
 use crate::prelude::*;
-use std::mem::ManuallyDrop;
 
 impl<'ui> Ui<'ui> {
     /// Creates a new [`Tab`].
@@ -19,7 +16,11 @@ impl<'ui> Ui<'ui> {
     }
 }
 
-def_subcontrol!(ty: Tab, handle: uiTab,);
+def_subcontrol!(
+    docs: "",
+    ty: Tab,
+    handle: uiTab,
+);
 
 impl<'ui> Tab<'ui> {
     /// Appends a page.
@@ -28,7 +29,7 @@ impl<'ui> Tab<'ui> {
         name: impl AsRef<str>,
         control: &mut impl DerefMut<Target = Control<'ui>>,
     ) -> Result<(), crate::Error> {
-        let control = ManuallyDrop::new(control);
+        control.make_child();
         let name = make_cstring!(name.as_ref());
         unsafe { uiTabAppend(self.as_ptr(), name.as_ptr(), control.as_ptr()) };
 
@@ -42,7 +43,7 @@ impl<'ui> Tab<'ui> {
         index: u16,
         control: &mut impl DerefMut<Target = Control<'ui>>,
     ) -> Result<(), crate::Error> {
-        let control = ManuallyDrop::new(control);
+        control.make_child();
         let name = make_cstring!(name.as_ref());
         unsafe { uiTabInsertAt(self.as_ptr(), name.as_ptr(), index.into(), control.as_ptr()) }
 
