@@ -1,9 +1,10 @@
-// This Source Code Form is subject to the terms of the Mozilla Public
-// License, v. 2.0. If a copy of the MPL was not distributed with this
-// file, You can obtain one at https://mozilla.org/MPL/2.0/.
+// SPDX-License-Identifier: MPL-2.0
+
+//! [`Ui`].
+
+use std::{ffi::CStr, os::raw::c_char, ptr};
 
 use crate::prelude::*;
-use std::{ffi::CStr, os::raw::c_char, ptr};
 
 impl Ui<'_> {
     /// Runs *libui-ng*.
@@ -52,9 +53,11 @@ impl Ui<'_> {
             }
         }
 
-        result.map_err(|cause| crate::Error::LibuiFn {
-            name: "uiInit",
-            cause: Some(cause),
+        result.map_err(|cause| {
+            crate::Error::LibuiFn {
+                name: "uiInit",
+                cause: Some(cause),
+            }
         })
     }
 
@@ -101,7 +104,10 @@ macro_rules! def_ui {
             $(
                 #[allow(clippy::mut_from_ref)]
                 pub(crate) fn $fn<'a>(&'a self, value: $crate::$ty<'ui>) -> &'a mut $crate::$ty<'ui> {
-                    self.$field.alloc(value)
+                    let result = self.$field.alloc(value);
+                    tracing::debug!("Allocated new `{}` @ {:#?}", stringify!($ty), result.as_ptr());
+
+                    result
                 }
             )*
         }
@@ -109,18 +115,14 @@ macro_rules! def_ui {
 }
 
 def_ui![
+    {
+        field: windows,
+        fn: alloc_window() -> Window,
+    },
     {
         field: areas,
         fn: alloc_area() -> Area,
     },
-    {
-        field: buttons,
-        fn: alloc_button() -> Button,
-    },
-    {
-        field: checkboxes,
-        fn: alloc_checkbox() -> Checkbox,
-    },
     {
         field: comboboxes,
         fn: alloc_combobox() -> Combobox,
@@ -137,6 +139,26 @@ def_ui![
         field: groups,
         fn: alloc_group() -> Group,
     },
+    {
+        field: tabs,
+        fn: alloc_tab() -> Tab,
+    },
+    {
+        field: tables,
+        fn: alloc_table() -> Table,
+    },
+    {
+        field: uniboxes,
+        fn: alloc_unibox() -> UniBox,
+    },
+    {
+        field: buttons,
+        fn: alloc_button() -> Button,
+    },
+    {
+        field: checkboxes,
+        fn: alloc_checkbox() -> Checkbox,
+    },
     {
         field: images,
         fn: alloc_image() -> Image,
@@ -145,14 +167,6 @@ def_ui![
         field: labels,
         fn: alloc_label() -> Label,
     },
-    {
-        field: menus,
-        fn: alloc_menu() -> Menu,
-    },
-    {
-        field: menu_items,
-        fn: alloc_menu_item() -> MenuItem,
-    },
     {
         field: progress_bars,
         fn: alloc_progress_bar() -> ProgressBar,
@@ -166,19 +180,11 @@ def_ui![
         fn: alloc_spinbox() -> Spinbox,
     },
     {
-        field: tabs,
-        fn: alloc_tab() -> Tab,
+        field: menus,
+        fn: alloc_menu() -> Menu,
     },
     {
-        field: tables,
-        fn: alloc_table() -> Table,
-    },
-    {
-        field: uniboxes,
-        fn: alloc_unibox() -> UniBox,
-    },
-    {
-        field: windows,
-        fn: alloc_window() -> Window,
+        field: menu_items,
+        fn: alloc_menu_item() -> MenuItem,
     },
 ];
