@@ -1,12 +1,11 @@
-// This Source Code Form is subject to the terms of the Mozilla Public
-// License, v. 2.0. If a copy of the MPL was not distributed with this
-// file, You can obtain one at https://mozilla.org/MPL/2.0/.
+// SPDX-License-Identifier: MPL-2.0
 
 //! [`Window`].
 
-use crate::prelude::*;
 use std::{os::raw::c_void, ptr};
 
+use crate::prelude::*;
+
 impl<'ui> Ui<'ui> {
     /// Creates a new [`Window`].
     pub fn create_window(
@@ -62,6 +61,7 @@ impl<'ui> Ui<'ui> {
 }
 
 def_subcontrol!(
+    docs: "",
     ty: Window,
     handle: uiWindow,
     cb_fns: [
@@ -225,5 +225,4 @@ macro_rules! impl_present_fn {
 }
 
 impl_present_fn!(present_alert, uiMsgBox,);
-
 impl_present_fn!(present_error, uiMsgBoxError,);
